summaryrefslogtreecommitdiff
path: root/src/installationmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/installationmanager.h')
-rw-r--r--src/installationmanager.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/installationmanager.h b/src/installationmanager.h
index 4e4f4346..149295a6 100644
--- a/src/installationmanager.h
+++ b/src/installationmanager.h
@@ -68,9 +68,11 @@ public:
* @brief Notify all installer plugins that an installation is about to start.
*
* @param archive Path to the archive that is going to be installed.
* @param currentMod The mod being re-installed, or a null pointer for new installation.
*/
- void notifyInstallationStart(QString const& archive, ModInfo::Ptr currentMod);
+ void notifyInstallationStart(QString const& archive, bool reinstallation, ModInfo::Ptr currentMod);
/**
* @brief notify all installer plugins that an installation has ended.
@@ -68,9 +68,11 @@ public:
*
* @param archive Path to the archive that is going to be installed.
- * @param currentMod The mod being re-installed, or a null pointer for new installation.
+ * @param reinstallation True if this is a reinstallation, false otherwise.
+ * @param currentMod The installed mod corresponding to the archive being installed, or a null
+ * if there is no such mod.
*/